@@ -1,4 +1,4 @@
-#!/usr/bin/env python2
+#!/usr/bin/env python3
 
 # Large Room Example
 # Written in 2012, 2013, 2014 by Julian Marchant <onpon4@riseup.net>
@@ -12,18 +12,6 @@
 # along with this software. If not, see
 # <http://creativecommons.org/publicdomain/zero/1.0/>.
 
-"""Split-screen Example
-
-This is an example of split-screening being used, where two players see
-two different parts of the room.
-
-"""
-
-from __future__ import division
-from __future__ import absolute_import
-from __future__ import print_function
-from __future__ import unicode_literals
-
 import sge
 import random
 
@@ -39,8 +27,7 @@ class Game(sge.Game):
 
 class Circle(sge.StellarClass):
     def __init__(self, x, y, player=0):
-        super(Circle, self).__init__(x, y, 1, sprite='circle',
-                                     collision_precise=True)
+        super().__init__(x, y, 1, sprite='circle', collision_precise=True)
         self.player = player
         self.normal_image_blend = ['red', 'blue', 'yellow', 'green'][self.player]
         self.image_alpha = 128
@@ -49,14 +36,14 @@ class Circle(sge.StellarClass):
         self.image_blend = self.normal_image_blend
         for obj in sge.game.current_room.objects:
             if (obj is not self and isinstance(obj, Circle) and
-                    self.collides(obj)):
+                    self.collision(obj)):
                 self.image_blend = 'olive'
                 break
 
     def event_create(self):
         self.set_color()
 
-    def event_step(self, time_passed):
+    def event_step(self, time_passed, delta_mult):
         left_key = ['left', 'a', 'j', 'kp_4'][self.player]
         right_key = ['right', 'd', 'l', 'kp_6'][self.player]
         up_key = ['up', 'w', 'i', 'kp_8'][self.player]
@@ -98,15 +85,15 @@ def main():
 
     # Create objects
     objects = []
-    for i in xrange(1):
+    for i in range(1):
         circle = Circle(random.randrange(0, 640), random.randrange(0, 480),
                         i)
         objects.append(circle)
 
     # Create views
     views = []
-    for x in xrange(1):
-        for y in xrange(1):
+    for x in range(1):
+        for y in range(1):
             views.append(sge.View(0, 0, 320 * x, 240 * y, 320, 240))
 
     # Create rooms
