@@ -1,4 +1,4 @@
-#!/usr/bin/env python3
+#!/usr/bin/env python2
 
 # Pong Example
 # Written in 2013, 2014 by Julian Marchant <onpon4@riseup.net>
@@ -12,6 +12,11 @@
 # along with this software. If not, see
 # <http://creativecommons.org/publicdomain/zero/1.0/>.
 
+from __future__ import division
+from __future__ import absolute_import
+from __future__ import print_function
+from __future__ import unicode_literals
+
 import sge
 
 PADDLE_SPEED = 4
@@ -106,7 +111,7 @@ class Player(sge.StellarClass):
             self.hit_direction = -1
 
         y = sge.game.height / 2
-        super().__init__(x, y, 0, sprite="paddle")
+        super(Player, self).__init__(x, y, 0, sprite="paddle")
 
     def event_create(self):
         self.v_score = 0
@@ -146,7 +151,7 @@ class Ball(sge.StellarClass):
     def __init__(self):
         x = sge.game.width / 2
         y = sge.game.height / 2
-        super().__init__(x, y, 1, sprite="ball")
+        super(Ball, self).__init__(x, y, 1, sprite="ball")
 
     def event_create(self):
         refresh_hud()
