@@ -1,4 +1,4 @@
-#!/usr/bin/env python2
+#!/usr/bin/env python3
 
 # Rotation Example
 # Written in 2012, 2013, 2014 by Julian Marchant <onpon4@riseup.net>
@@ -12,11 +12,6 @@
 # along with this software. If not, see
 # <http://creativecommons.org/publicdomain/zero/1.0/>.
 
-from __future__ import division
-from __future__ import absolute_import
-from __future__ import print_function
-from __future__ import unicode_literals
-
 import sge
 import random
 
@@ -32,7 +27,7 @@ class Game(sge.Game):
 
 class Circle(sge.StellarClass):
     def __init__(self, x, y):
-        super(Circle, self).__init__(x, y, 5, sprite='rotator', regulate_origin=True,
+        super().__init__(x, y, 5, sprite='rotator', regulate_origin=True,
                          collision_precise=True)
 
     def event_create(self):
