@@ -15,6 +15,11 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with the Pygame SGE.  If not, see <http://www.gnu.org/licenses/>.
 
+from __future__ import division
+from __future__ import absolute_import
+from __future__ import print_function
+from __future__ import unicode_literals
+
 import os
 import warnings
 
@@ -26,7 +31,7 @@ import sge
 __all__ = ['Game']
 
 
-class Game:
+class Game(object):
 
     """Class which handles the game.
 
@@ -263,10 +268,11 @@ class Game:
             for path in sge.image_directories:
                 try:
                     image = pygame.image.load(os.path.join(path, value))
-                    pygame.display.set_icon(image)
-                    break
                 except pygame.error:
                     continue
+                else:
+                    pygame.display.set_icon(image)
+                    break
 
     def __init__(self, width=640, height=480, fullscreen=False, scale=0,
                  scale_proportional=True, scale_smooth=False, fps=60,
@@ -286,6 +292,8 @@ class Game:
         pygame.mixer.pre_init(channels=2, buffer=1024)
         pygame.init()
 
+        pygame.mixer.music.set_endevent(sge.MUSIC_END_EVENT)
+
         sge.game = self
 
         self._width = width
@@ -331,12 +339,12 @@ class Game:
         # Setup sound channels
         self._available_channels = []
         if pygame.mixer.get_init():
-            for i in range(pygame.mixer.get_num_channels()):
+            for i in xrange(pygame.mixer.get_num_channels()):
                 self._available_channels.append(pygame.mixer.Channel(i))
 
         # Setup joysticks
         if pygame.joystick.get_init():
-            for i in range(pygame.joystick.get_count()):
+            for i in xrange(pygame.joystick.get_count()):
                 joy = pygame.joystick.Joystick(i)
                 joy.init()
                 n = joy.get_name()
@@ -438,23 +446,35 @@ class Game:
                 # Pygame events
                 for event in pygame.event.get():
                     if event.type == pygame.KEYDOWN:
-                        k = sge.KEY_NAMES[event.key]
-                        self.event_key_press(k, event.unicode)
-                        self.current_room.event_key_press(k, event.unicode)
-                        for obj in self.current_room.objects:
-                            if obj.active:
-                                obj.event_key_press(k, event.unicode)
-                            else:
-                                obj.event_inactive_key_press(k, event.unicode)
+                        try:
+                            k = sge.KEY_NAMES[event.key]
+                        except KeyError:
+                            w = "Don't know how to handle the key, ``{}``.".format(
+                                event.key)
+                            warnings.warn(w)
+                        else:
+                            self.event_key_press(k, event.unicode)
+                            self.current_room.event_key_press(k, event.unicode)
+                            for obj in self.current_room.objects:
+                                if obj.active:
+                                    obj.event_key_press(k, event.unicode)
+                                else:
+                                    obj.event_inactive_key_press(
+                                        k, event.unicode)
                     elif event.type == pygame.KEYUP:
-                        k = sge.KEY_NAMES[event.key]
-                        self.event_key_release(k)
-                        self.current_room.event_key_release(k)
-                        for obj in self.current_room.objects:
-                            if obj.active:
-                                obj.event_key_release(k)
-                            else:
-                                obj.event_inactive_key_release(k)
+                        try:
+                            k = sge.KEY_NAMES[event.key]
+                        except KeyError:
+                            w = "Don't know how to handle the key, ``{}``.".format(
+                                event.key)
+                        else:
+                            self.event_key_release(k)
+                            self.current_room.event_key_release(k)
+                            for obj in self.current_room.objects:
+                                if obj.active:
+                                    obj.event_key_release(k)
+                                else:
+                                    obj.event_inactive_key_release(k)
                     elif event.type == pygame.MOUSEMOTION:
                         mx, my = event.pos
                         self.mouse.mouse_x = mx - self._x
@@ -588,6 +608,10 @@ class Game:
                         self._window_width = event.w
                         self._window_height = event.h
                         self._set_mode()
+                    elif event.type == sge.MUSIC_END_EVENT:
+                        if self._music_queue:
+                            music = self._music_queue.pop(0)
+                            music[0].play(*music[1:])
 
                 real_time_passed = self._clock.tick(self.fps)
 
@@ -895,6 +919,10 @@ class Game:
                                                         (event.w, event.h))
                     background = pygame.transform.scale(orig_background,
                                                         (event.w, event.h))
+                elif event.type == sge.MUSIC_END_EVENT:
+                    if self._music_queue:
+                        music = self._music_queue.pop(0)
+                        music[0].play(*music[1:])
 
             # Time management
             self._clock.tick(self.fps)
@@ -1776,7 +1804,7 @@ class Game:
         new_num_channels = old_num_channels + 4
         pygame.mixer.set_num_channels(new_num_channels)
 
-        for i in range(old_num_channels, new_num_channels):
+        for i in xrange(old_num_channels, new_num_channels):
             self._available_channels.append(pygame.mixer.Channel(i))
 
     def _handle_music(self):
@@ -1797,7 +1825,3 @@ class Game:
 
                 if timeout and time_played >= timeout:
                     self._music.stop()
-                    
-            elif self._music_queue:
-                music = self._music_queue.pop(0)
-                music[0].play(*music[1:])
