@@ -15,11 +15,6 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with the Pygame SGE.  If not, see <http://www.gnu.org/licenses/>.
 
-from __future__ import division
-from __future__ import absolute_import
-from __future__ import print_function
-from __future__ import unicode_literals
-
 import os
 import warnings
 
@@ -31,7 +26,7 @@ import sge
 __all__ = ['Sprite']
 
 
-class Sprite(object):
+class Sprite:
 
     """Class which holds information for images and animations.
 
@@ -296,20 +291,23 @@ class Sprite(object):
                 # Load the single image
                 try:
                     img = pygame.image.load(fname_single)
-                    self._baseimages.append(img)
                 except pygame.error:
                     if sge.DEBUG:
                         print("Ignored {}; not a valid image.".format(fname_single))
+                else:
+                    self._baseimages.append(img)
 
             if not self._baseimages and any(fname_frames):
                 # Load the multiple images
                 for fname in fname_frames:
                     if fname:
                         try:
-                            self._baseimages.append(pygame.image.load(fname))
+                            img = pygame.image.load(fname)
                         except pygame.error:
                             if sge.DEBUG:
                                 print("Ignored {}; not a valid image.".format(fname))
+                        else:
+                            self._baseimages.append(img)
 
             if not self._baseimages and fname_strip:
                 # Load the strip (sprite sheet)
@@ -324,18 +322,19 @@ class Sprite(object):
 
                 try:
                     sheet = pygame.image.load(fname_strip)
+                except pygame.error:
+                    if sge.DEBUG:
+                        print("Ignored {}; not a valid image.".format(fname_strip))
+                else:
                     assert split[1][5:].isdigit()
                     n = int(split[1][5:])
 
                     img_w = max(1, sheet.get_width()) // n
                     img_h = max(1, sheet.get_height())
-                    for x in xrange(0, img_w * n, img_w):
+                    for x in range(0, img_w * n, img_w):
                         rect = pygame.Rect(x, 0, img_w, img_h)
                         img = sheet.subsurface(rect)
                         self._baseimages.append(img)
-                except pygame.error:
-                    if sge.DEBUG:
-                        print("Ignored {}; not a valid image.".format(fname_strip))
 
             if not self._baseimages:
                 print("Directories searched:")
@@ -442,7 +441,7 @@ class Sprite(object):
 
         """
         color = sge._get_pygame_color(color)
-        for i in xrange(self.frames):
+        for i in range(self.frames):
             if frame is None or frame % self.frames == i:
                 self._baseimages[i].set_at((x, y), color)
 
@@ -473,7 +472,7 @@ class Sprite(object):
         color = sge._get_pygame_color(color)
         thickness = abs(thickness)
 
-        for i in xrange(self.frames):
+        for i in range(self.frames):
             if frame is None or frame % self.frames == i:
                 if anti_alias and thickness == 1:
                     pygame.draw.aaline(self._baseimages[i], color, (x1, y1),
@@ -515,7 +514,7 @@ class Sprite(object):
 
         rect = pygame.Rect(x, y, width, height)
 
-        for i in xrange(self.frames):
+        for i in range(self.frames):
             if frame is None or frame % self.frames == i:
                 if fill is not None:
                     pygame.draw.rect(self._baseimages[i],
@@ -560,7 +559,7 @@ class Sprite(object):
 
         rect = pygame.Rect(x, y, width, height)
 
-        for i in xrange(self.frames):
+        for i in range(self.frames):
             if frame is None or frame % self.frames == i:
                 if fill is not None:
                     c = sge._get_pygame_color(fill)
@@ -602,7 +601,7 @@ class Sprite(object):
             # There's no point in trying in this case.
             return
 
-        for i in xrange(self.frames):
+        for i in range(self.frames):
             if frame is None or frame % self.frames == i:
                 if fill is not None:
                     c = sge._get_pygame_color(fill)
@@ -623,10 +622,10 @@ class Sprite(object):
         - ``sprite`` -- The sprite to draw with.
         - ``image`` -- The frame of ``sprite`` to draw with, where ``0``
           is the first frame.
-        - ``x`` -- The horizontal location relative to ``self`` to draw
-          ``sprite``.
-        - ``y`` -- The vertical location relative to ``self`` to draw
-          ``sprite``.
+        - ``x`` -- The horizontal location relative to ``self`` to
+          position the origin of ``sprite``.
+        - ``y`` -- The vertical location relative to ``self`` to
+          position the origin of ``sprite``.
         - ``frame`` -- The frame of the sprite to draw on, where ``0``
           is the first frame; set to :const:`None` to draw on all
           frames.
@@ -674,7 +673,7 @@ class Sprite(object):
             sge.BLEND_RGB_MAXIMUM: pygame.BLEND_RGB_MAX
             }.setdefault(blend_mode, 0)
 
-        for i in xrange(self.frames):
+        for i in range(self.frames):
             if frame is None or frame % self.frames == i:
                 self._baseimages[i].blit(sprite._baseimages[image], (x, y),
                                          None, pygame_flags)
@@ -757,7 +756,7 @@ class Sprite(object):
         text_rect = text_surf.get_rect()
         box_rect = box_surf.get_rect()
 
-        for i in xrange(len(lines)):
+        for i in range(len(lines)):
             rendered_text = font._font.render(lines[i], anti_alias, color)
             rect = rendered_text.get_rect()
             rect.top = i * font._font.get_linesize()
@@ -798,7 +797,7 @@ class Sprite(object):
         else:
             box_rect.top = y
 
-        for i in xrange(self.frames):
+        for i in range(self.frames):
             if frame is None or frame % self.frames == i:
                 self._baseimages[i].blit(box_surf, box_rect)
 
@@ -813,7 +812,7 @@ class Sprite(object):
           the first frame; set to :const:`None` to clear all frames.
 
         """
-        for i in xrange(self.frames):
+        for i in range(self.frames):
             if frame is None or frame % self.frames == i:
                 if self._baseimages[i].get_flags() & pygame.SRCALPHA:
                     color = pygame.Color(0, 0, 0, 0)
@@ -845,7 +844,7 @@ class Sprite(object):
         reel = pygame.Surface((w, h), pygame.SRCALPHA)
         reel.fill(pygame.Color(0, 0, 0, 0))
 
-        for i in xrange(self.frames):
+        for i in range(self.frames):
             reel.blit(self._baseimages[i], (self.width * i, 0))
 
         try:
@@ -904,14 +903,14 @@ class Sprite(object):
                    bbox_height=bbox_height)
         tileset = Sprite(name, origin_x=x, origin_y=y)
 
-        for i in xrange(1, rows):
-            for j in xrange(1, columns):
+        for i in range(1, rows):
+            for j in range(1, columns):
                 self.append_frame()
 
         self.draw_clear()
 
-        for i in xrange(rows):
-            for j in xrange(columns):
+        for i in range(rows):
+            for j in range(columns):
                 frame = i * columns + j
                 x_ = (width + xsep) * j
                 y_ = (height + ysep) * i
@@ -977,7 +976,7 @@ class Sprite(object):
         # methods to work properly, specifically whenever ``width`` and
         # ``height`` are set.  As a result, setting ``width`` and
         # ``height`` is destructive in this implementation.
-        for i in xrange(self.frames):
+        for i in range(self.frames):
             if sge.game.scale_smooth:
                 try:
                     self._baseimages[i] = pygame.transform.smoothscale(
@@ -1071,15 +1070,15 @@ class Sprite(object):
             image.lock()
             mask = []
             if image.get_flags() & pygame.SRCALPHA:
-                for x in xrange(image.get_width()):
+                for x in range(image.get_width()):
                     mask.append([])
-                    for y in xrange(image.get_height()):
+                    for y in range(image.get_height()):
                         mask[x].append(image.get_at((x, y)).a > 0)
             else:
                 colorkey = image.get_colorkey()
-                for x in xrange(image.get_width()):
+                for x in range(image.get_width()):
                     mask.append([])
-                    for y in xrange(image.get_height()):
+                    for y in range(image.get_height()):
                         mask[x].append(image.get_at((x, y)) == colorkey)
 
             image.unlock()
